Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-07-25 18:30:10 +0000
committerStijn Buys <ingar@osirion.org>2008-07-25 18:30:10 +0000
commit812bb37b7e73104d97da35eb3e66046495aaa305 (patch)
tree63ee32e2c53d35aeb3dc219c8caa211de5fbf0cd /src/core/netconnection.h
parentabe6c3dc6e6f9df40345d6aaf19f12fdfa3f3024 (diff)
minor cleanups
Diffstat (limited to 'src/core/netconnection.h')
-rw-r--r--src/core/netconnection.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/core/netconnection.h b/src/core/netconnection.h
index 4e8d9f9..da683f5 100644
--- a/src/core/netconnection.h
+++ b/src/core/netconnection.h
@@ -65,7 +65,7 @@ public:
/// send a command line to the remote server
void send_command(std::string const &cmdline);
- /// transmit messages in the outgoing queue to the remote server
+ /// transmit messages in the send queue to the remote server
void transmit();
void abort();
@@ -91,8 +91,8 @@ public:
State connection_state;
protected:
- /// add a message to the queue
- void send(std::string const &msg);
+ /// add a raw network message to the send queue
+ void send_raw(std::string const &msg);
/// receive incoming data and store messages
void receive();